/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.printpublisher.wizard;

import java.net.URL;

import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.wizard.WizardPage;

import eu.etaxonomy.cdm.print.PublishConfigurator;
import eu.etaxonomy.cdm.print.out.IPublishOutputModule;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>Abstract AbstractPublishWizardPage class.</p>
 *
 * @author n.hoffmann
 * @created Apr 27, 2010
 */
public abstract class AbstractPublishWizardPage extends WizardPage {

	protected AbstractPublishWizardPage(String pageName) {
		super(pageName);
	}
	
	public PublishConfigurator getConfigurator(){
		return ((AbstractPublishWizard) getWizard()).getConfigurator();
	}

	public void setConfigurator(PublishConfigurator configurator){
		((AbstractPublishWizard) getWizard()).setConfigurator(configurator);
	}

	public IPublishOutputModule getOutputModule(){
		IPublishOutputModule outputModule = ((AbstractPublishWizard) getWizard()).getOutputModule();
		if(outputModule == null)
			throw new IllegalStateException("OutputModule may not be null at this moment");
		return outputModule;
	}
	
	public void putDialogSettingValue(String key, String value){
		getDialogSettingSection().put(key, value);
	}
	
	public String getDialogSettingValue(String key){
		return getDialogSettingSection().get(key);
	} 
	
	public boolean getDialogSettingBooleanValue(String key){
		return getDialogSettingSection().getBoolean(key);
	}
	
	private IDialogSettings getDialogSettingSection(){
		IDialogSettings wizardDialogSetting = getWizard().getDialogSettings();
		if(wizardDialogSetting == null){
			throw new IllegalStateException("Wizards dialog setting may not be null");
		}
		
		IDialogSettings specificWizardDialogSection = getOrCreateSettingSection(wizardDialogSetting, getWizard().getClass().getName());
		
		String dataSource = null;
		if(getConfigurator().isLocal()){
			dataSource = CdmStore.getActiveCdmSource().getName();
		}else if(getConfigurator().isRemote()){
			URL serviceUrl = getConfigurator().getWebserviceUrl();
			dataSource = serviceUrl.toExternalForm();
		}else{
			throw new IllegalStateException("Print publisher configurator should be either local or remote");
		}		
		
		IDialogSettings specificDataSourceDialogSection = getOrCreateSettingSection(specificWizardDialogSection, dataSource);
		
		return specificDataSourceDialogSection;
	}
	
	private IDialogSettings getOrCreateSettingSection(IDialogSettings setting, String sectionName){
		IDialogSettings section = setting.getSection(sectionName);
		
		if(section == null){
			section = setting.addNewSection(sectionName);
		}
		
		return section;
	}
}
